/**
 * Copyright 2017 Julon Lou <contact@julonlou.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var momentJs = _interopDefault(require('moment'));

var LibraryModule = {
  install: function install(Vue, options) {
    // default to moment js lib
    var moment = momentJs;

    // if moment is passed as an option
    if (options && options.moment) {
      moment = options.moment;
    }

    /* eslint-disable */
    // make moment accessible in components with this.$moment
    Vue.prototype.$moment = moment;
    Vue.prototype.$duration = moment.duration;

    // declare this moment instance as a global function for vuex, etc
    Vue.moment = moment;
    /* eslint-enable */

    // filter to wire moment
    Vue.filter("moment", function (value) {
      for (var _len = arguments.length, args = Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
        args[_key - 2] = arguments[_key];
      }

      var isUtc = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

      // add utc support on moment(true)
      var filterMoment = isUtc ? moment.utc : moment;
      return filterMoment(args);
    });

    // filter to wire moment duration
    Vue.filter("duration", function (value, unit) {
      return moment.duration(value, unit);
    });
  }
};

exports['default'] = LibraryModule;
